@@ -50,7 +50,7 @@ class DeletedAttribute:
     object is queried for attributes.
     """
 
-    __slots__ = ["_callback"]
+    __slots__ = ("_callback",)
 
     def __init__(self, callback: Typing.Callable):
         self._callback = callback
@@ -116,7 +116,7 @@ class Slots:
     instances, with explicitly declared attributes in their `__slots__`.
     """
 
-    __slots__ = []
+    __slots__ = ()
 
     def __init__(self, **kwargs):
         """
@@ -172,14 +172,22 @@ class Slots:
         """
         delattr(self, variable)
 
-    def _repr(self, items: Typing.Generator):
+    @staticmethod
+    def _repr(items: Typing.Iterable[Typing.Tuple[Typing.Any, Typing.Any]]):
         """
+        Individually wraps the produced ``items`` values in a visible
+        string for an instance's repr.
         """
         for name, value in items:
             yield f"{name}={repr(value)}"
 
-    def _omitted_repr(self, items: Typing.Generator):
+    @staticmethod
+    def _omitted_repr(
+        items: Typing.Iterable[Typing.Tuple[Typing.Any, Typing.Any]]
+    ):
         """
+        Individually wraps the produced ``items`` values in a masked
+        string for an instance's repr.
         """
         for name, value in items:
             exists = (value and "is <truthy>") or "is <falsey>"
@@ -198,7 +206,7 @@ class Slots:
             items = spacer.join(self._repr(self.items()))
         else:
             items = spacer.join(self._omitted_repr(self.items()))
-        return f"{cls}{new_line + items + f',{sep}' if items else ''})"
+        return f"{cls}{f'{new_line}{items},{sep}' if items else ''})"
 
     async def __aiter__(self):
         """
@@ -257,6 +265,8 @@ class Namespace(Slots):
     mappings into stand-alone, first-class modules.
     """
 
+    __slots__ = ("__dict__",)
+
     def __init__(self, mapping={}, **kwargs):
         """
         Maps the user-defined mapping & kwargs to the Namespace's
@@ -352,7 +362,7 @@ class Namespace(Slots):
             items = spacer.join(self._repr(items))
         else:
             items = spacer.join(self._omitted_repr(items))
-        return f"{cls}{new_line + items + f',{sep}' if items else ''})"
+        return f"{cls}{f'{new_line}{items},{sep}' if items else ''})"
 
     async def __aiter__(self):
         """
@@ -424,7 +434,7 @@ chunky2048_constants = OpenNamespace(
     LEFT_PAD=8 * b"\x5c",
     MAX_BLOCK_ID_BYTES=32,
     MINIMUM_BLOCK_ID_BYTES=16,
-    MINIMUM_KEY_BYTES=32,
+    MINIMUM_KEY_BYTES=64,
     PADDING_KEY="padding_key",
     PADDING_KEY_BYTES=32,
     PLAINTEXT="plaintext",
@@ -452,9 +462,11 @@ chunky2048_constants.namespace.update(
         CIPHERTEXT_SLICE=slice(HEADER_BYTES, None),
         DIGEST_NIBBLES=2 * DIGEST_BYTES,
         HEADER_NIBBLES=2 * HEADER_BYTES,
+        HEADER_SLICE=slice(None, HEADER_BYTES),
         HMAC_NIBBLES=2 * HMAC_BYTES,
         HMAC_SLICE=slice(HMAC_BYTES),
         INNER_HEADER_NIBBLES=2 * INNER_HEADER_BYTES,
+        INNER_HEADER_SLICE=slice(None, INNER_HEADER_BYTES),
         KEY_NIBBLES=2 * KEY_BYTES,
         MAX_BLOCK_ID_NIBBLES=2 * MAX_BLOCK_ID_BYTES,
         MINIMUM_BLOCK_ID_NIBBLES=2 * MINIMUM_BLOCK_ID_BYTES,
