@@ -43,9 +43,13 @@ class DebugControl:
     Enabling debugging reveals omitted values in object ``repr``s &
     turns on asyncio's debugging.
     """
-    _switches = []
+
+    __slots__ = ()
+
     _DEBUG_MODE = False
 
+    _switches = []
+
     @classmethod
     def is_debugging(cls):
         return cls._DEBUG_MODE
@@ -68,345 +72,393 @@ class DebugControl:
             toggle()
 
 
+class AsyncDebugTools:
+    """
+    A simple class used for displaying & calculating runtime statistics
+    on asynchronous functions.
+    """
+
+    __slots__ = (
+        "args",
+        "func",
+        "kwargs",
+        "log_entry",
+        "return_value",
+        "time_after",
+        "time_before",
+        "time_elapsed",
+        "time_total",
+        "timer_average",
+        "timer_standard_deviation",
+        "timer_variance_sum",
+        "times_run",
+    )
+
+    def __init__(self):
+        """
+        Sets timing variables.
+        """
+        self.times_run = 0
+        self.time_total = 0.0
+        self.timer_variance_sum = 0
+        self.return_value = None
+
+    async def ainitialize_run(self, func, *a, **kw):
+        """
+        Captures the parameters to a wrapped async function & displays
+        the incremented call number for the function.
+        """
+        self.args = a
+        self.kwargs = kw
+        self.func = func
+
+    async def _aoutput_times_used(self):
+        """
+        Displays the number of times the wrapped async function has been
+        run.
+        """
+        return f"Test #{self.times_run}"
+
+    @staticmethod
+    async def _aoutput_time_start():
+        """
+        Displays the datetime of when the function has been called.
+        """
+        return f"Time Start:\t{datetime.datetime.now()}"
+
+    async def _aoutput_happening_now(self):
+        """
+        Displays the currently running wrapped async function.
+        """
+        current_func = f"Function:      {self.func.__qualname__}\n"
+        current_func += f"{repr(self.func)}"
+        return current_func
+
+    async def _aoutput_arguments(self):
+        """
+        Displays the wrapped async function's supplied parameters.
+        """
+        for arg in self.args:
+            yield f"Argument:      {repr(arg)}"
+        for kwarg in self.kwargs.items():
+            yield f"KW Argument:   {str(kwarg)}"
+
+    async def _atime_the_function(self):
+        """
+        Captures the runtime of an async function.
+        """
+        self.time_before = time()
+        self.return_value = await self.func(
+            *self.args, **self.kwargs
+        )
+        self.time_after = time()
+
+    async def _aoutput_time_elapsed(self):
+        """
+        Displays the captured runtime of the wrapped async funciton.
+        """
+        self.time_elapsed = self.time_after - self.time_before
+        elapsed = f"{self.func.__qualname__}\n"
+        elapsed += "Time Elapsed:         "
+        elapsed += f"{self.time_elapsed} seconds."
+        return elapsed
+
+    async def _astart_timer(self):
+        """
+        Runs the wrapped async function & displays some runtime stats.
+        """
+        self.times_run += 1
+        self.log_entry = [
+            await self._aoutput_times_used(),
+            await self._aoutput_time_start(),
+            await self._aoutput_happening_now(),
+            *[arg async for arg in self._aoutput_arguments()],
+        ]
+        await self._atime_the_function()
+        self.log_entry.append(await self._aoutput_time_elapsed())
+
+    async def _asum_runtimes(self):
+        """
+        Add the runtime of the current wrapped async function's call.
+        """
+        self.time_total += self.time_after - self.time_before
+
+    async def _aoutput_average_runtime(self):
+        """
+        Calculates & displays the average runtime of the wrapped async
+        function.
+        """
+        self.timer_average = self.time_total / float(self.times_run)
+        return f"Average Elapsed Time: {self.timer_average} seconds."
+
+    async def _asum_of_variances(self):
+        """
+        Adds the current runtime variance to the aggregated sum.
+        """
+        self.timer_variance_sum += (
+            self.time_elapsed - self.timer_average
+        ) ** 2
+        return self.timer_variance_sum
+
+    async def _aaverage_variance(self):
+        """
+        Calculates the variance of runtimes of the wrapped async
+        function.
+        """
+        return await self._asum_of_variances() / self.times_run
+
+    async def _astandard_deviation(self):
+        """
+        Calculates the standard deviation of runtimes of the wrapped
+        async function.
+        """
+        return await self._aaverage_variance() ** 0.5
+
+    async def _aoutput_standard_deviation(self):
+        """
+        Calculates & displays the standard deviation of runtimes of the
+        wrapped async function.
+        """
+        self.timer_standard_deviation = await self._astandard_deviation()
+        std_deviation = "Standard Deviation:   "
+        std_deviation += f"{self.timer_standard_deviation} seconds."
+        return std_deviation
+
+    async def _aoutput_return_value(self, return_value):
+        """
+        Displays the return value of the wrapped async function.
+        """
+        return f"Return Value:  {repr(return_value)}"
+
+    @staticmethod
+    async def _aoutput_trace_call():
+        """
+        Displays the name of the function which has called the wrapped
+        async function in user code by inspecting the stack.
+        """
+        calling_function = inspect.stack()[2][3]
+        return f"Calling Function: {calling_function}\n\n"
+
+    async def _aclose_timer(self):
+        """
+        Does final calculations on the aggregate runtime statistics of
+        the wrapped async function & displays the results.
+        """
+        await self._asum_runtimes()
+        self.log_entry += [
+            await self._aoutput_average_runtime(),
+            await self._aoutput_standard_deviation(),
+            await self._aoutput_return_value(self.return_value),
+            await self._aoutput_trace_call(),
+        ]
+        add_to_log("\n".join(self.log_entry))
+
+    async def arun(self):
+        """
+        Runs the timer.
+        """
+        await self._astart_timer()
+        await self._aclose_timer()
+
+
 class DebugTools:
     """
     A simple class used for displaying & calculating runtime statistics
     on synchronous functions.
     """
 
+    __slots__ = (
+        "args",
+        "func",
+        "kwargs",
+        "log_entry",
+        "return_value",
+        "time_after",
+        "time_before",
+        "time_elapsed",
+        "time_total",
+        "timer_average",
+        "timer_standard_deviation",
+        "timer_variance_sum",
+        "times_run",
+    )
+
     def __init__(self):
         """
         Sets timing variables.
         """
         self.times_run = 0
-        self.timer_sum = 0.0
-        self.variance_sum = 0
+        self.time_total = 0.0
+        self.timer_variance_sum = 0
         self.return_value = None
 
-    def initiate_timer_func(self, *a, **kw):
+    def initialize_run(self, func, *a, **kw):
         """
         Captures the parameters to a wrapped sync function & displays
         the incremented call number for the function.
         """
-        self.times_run += 1
-        self.arg_tuple = a
-        self.kw_dict = kw
-        self.print_times_used()
+        self.args = a
+        self.kwargs = kw
+        self.func = func
 
-    def print_times_used(self):
+    def _output_times_used(self):
         """
         Displays the number of times the wrapped sync function has been
         run.
         """
-        add_to_log(f"Test #{self.times_run}")
-
-    def start_the_timer(self, decorated_func):
-        """
-        Runs the wrapped sync function & displays some runtime stats.
-        """
-        self.print_time_start()
-        self.print_happening_now(decorated_func)
-        self.print_arguments()
-        self.time_the_function()
-        self.print_time_elapsed()
+        return f"Test #{self.times_run}"
 
     @staticmethod
-    def print_time_start():
+    def _output_time_start():
         """
         Displays the datetime of when the function has been called.
         """
-        add_to_log(f"Time Start:    {datetime.datetime.now()}")
+        return f"Time Start:    {datetime.datetime.now()}"
 
-    def print_happening_now(self, decorated_func):
+    def _output_happening_now(self):
         """
         Displays the currently running wrapped sync function.
         """
-        self.timed_func = decorated_func
-        print_string = f"Function:      {decorated_func.__name__}\n"
-        print_string += f"{repr(decorated_func)}"
-        add_to_log(print_string)
+        current_func = f"Function:      {self.func.__qualname__}\n"
+        current_func += f"{repr(self.func)}"
+        return current_func
 
-    def print_arguments(self):
+    def _output_arguments(self):
         """
         Displays the wrapped sync function's supplied parameters.
         """
-        for arg in self.arg_tuple:
-            add_to_log(f"Argument:      {repr(arg)}")
-        for kwarg in self.kw_dict.items():
-            add_to_log(f"KW Argument:   {str(kwarg)}")
+        for arg in self.args:
+            yield f"Argument:      {repr(arg)}"
+        for kwarg in self.kwargs.items():
+            yield f"KW Argument:   {str(kwarg)}"
 
-    def time_the_function(self):
+    def _time_the_function(self):
         """
         Captures the runtime of an sync function.
         """
         self.time_before = time()
-        self.return_value = self.timed_func(
-            *self.arg_tuple, **self.kw_dict
+        self.return_value = self.func(
+            *self.args, **self.kwargs
         )
         self.time_after = time()
 
-    def print_time_elapsed(self):
+    def _output_time_elapsed(self):
         """
         Displays the captured runtime of the wrapped sync funciton.
         """
         self.time_elapsed = self.time_after - self.time_before
-        print_string = f"{self.timed_func.__name__}\n"
-        print_string += "Time Elapsed:         "
-        print_string += f"{self.time_elapsed} seconds."
-        add_to_log(print_string)
+        elapsed = f"{self.func.__qualname__}\n"
+        elapsed += "Time Elapsed:         "
+        elapsed += f"{self.time_elapsed} seconds."
+        return elapsed
 
-    def close_timer(self):
+    def _start_timer(self):
         """
-        Does final calculations on the aggregate runtime statistics of
-        the wrapped sync function & displays the results.
+        Runs the wrapped sync function & displays some runtime stats.
         """
-        self.sum_runtimes()
-        self.print_average_runtime()
-        self.print_standard_deviation()
-        self.print_return_value(self.return_value)
-        # self.print_source_code()
+        self.times_run += 1
+        self.log_entry = [
+            self._output_times_used(),
+            self._output_time_start(),
+            self._output_happening_now(),
+            *self._output_arguments(),
+        ]
+        self._time_the_function()
+        self.log_entry.append(self._output_time_elapsed())
 
-    def sum_runtimes(self):
+    def _sum_runtimes(self):
         """
         Add the runtime of the current wrapped sync function's call.
         """
-        self.timer_sum += self.time_after - self.time_before
+        self.time_total += self.time_after - self.time_before
 
-    def print_average_runtime(self):
+    def _output_average_runtime(self):
         """
         Calculates & displays the average runtime of the wrapped sync
         function.
         """
-        self.time_average = self.timer_sum / float(self.times_run)
-        add_to_log(f"Average Elapsed Time: {self.time_average} seconds.")
+        self.timer_average = self.time_total / float(self.times_run)
+        return f"Average Elapsed Time: {self.timer_average} seconds."
 
-    def print_standard_deviation(self):
+    def _sum_of_variances(self):
         """
-        Calculates & displays the standard deviation of runtimes of the
-        wrapped sync function.
+        Adds the current runtime variance to the aggregated sum.
         """
-        print_string = "Standard Deviation:   "
-        print_string += f"{self.standard_deviation()} seconds."
-        add_to_log(print_string)
+        self.timer_variance_sum += (
+            self.time_elapsed - self.timer_average
+        ) ** 2
+        return self.timer_variance_sum
 
-    def standard_deviation(self):
-        """
-        Calculates the standard deviation of runtimes of the wrapped
-        sync function.
-        """
-        return self.average_variance() ** 0.5
-
-    def average_variance(self):
+    def _average_variance(self):
         """
         Calculates the variance of runtimes of the wrapped sync
         function.
         """
-        return self.sum_of_variances() / self.times_run
+        return self._sum_of_variances() / self.times_run
 
-    def sum_of_variances(self):
+    def _standard_deviation(self):
         """
-        Adds the current runtime variance to the aggregated sum.
+        Calculates the standard deviation of runtimes of the wrapped
+        sync function.
         """
-        self.variance_sum += (
-            self.time_elapsed - self.time_average
-        ) ** 2
-        return self.variance_sum
+        return self._average_variance() ** 0.5
 
-    def print_return_value(self, return_value):
+    def _output_standard_deviation(self):
+        """
+        Calculates & displays the standard deviation of runtimes of the
+        wrapped sync function.
+        """
+        self.timer_standard_deviation = self._standard_deviation()
+        std_deviation = "Standard Deviation:   "
+        std_deviation += f"{self.timer_standard_deviation} seconds."
+        return std_deviation
+
+    def _output_return_value(self, return_value):
         """
         Displays the return value of the wrapped sync function.
         """
-        add_to_log(f"Return Value:  {repr(return_value)}")
-
-    def print_source_code(self):
-        """
-        Prints the source code of the currently running wrapped function.
-        """
-        add_to_log(f"Source Code:\n{inspect.getsource(self.timed_func)}")
+        return f"Return Value:  {repr(return_value)}"
 
     @staticmethod
-    def print_trace_call():
+    def _output_trace_call():
         """
         Displays the name of the function which has called the wrapped
         function in user code by inspecting the stack.
         """
         calling_function = inspect.stack()[2][3]
-        add_to_log(f"Calling Function: {calling_function}\n\n")
+        return f"Calling Function: {calling_function}\n\n"
 
-
-class AsyncDebugTools(DebugTools):
-    """
-    A simple class used for displaying & calculating runtime statistics
-    on asynchronous functions.
-    """
-
-    def __init__(self):
-        """
-        Sets timing variables.
-        """
-        self.times_run = 0
-        self.timer_sum = 0.0
-        self.variance_sum = 0
-        self.return_value = None
-
-    async def ainitiate_timer_func(self, *a, **kw):
-        """
-        Captures the parameters to a wrapped async function & displays
-        the incremented call number for the function.
-        """
-        self.times_run += 1
-        self.arg_tuple = a
-        self.kw_dict = kw
-        await self.aprint_times_used()
-
-    async def aprint_times_used(self):
-        """
-        Displays the number of times the wrapped async function has been
-        run.
-        """
-        add_to_log(f"Test #{self.times_run}")
-
-    async def astart_the_timer(self, decorated_func):
-        """
-        Runs the wrapped async function & displays some runtime stats.
-        """
-        await self.aprint_time_start()
-        await self.aprint_happening_now(decorated_func)
-        await self.aprint_arguments()
-        await self.atime_the_function()
-        await self.aprint_time_elapsed()
-
-    @staticmethod
-    async def aprint_time_start():
-        """
-        Displays the datetime of when the function has been called.
-        """
-        add_to_log(f"Time Start:\t{datetime.datetime.now()}")
-
-    async def aprint_happening_now(self, decorated_func):
-        """
-        Displays the currently running wrapped async function.
-        """
-        self.timed_func = decorated_func
-        print_string = f"Function:\t{decorated_func.__qualname__}\n"
-        print_string += f"{repr(decorated_func)}"
-        add_to_log(print_string)
-
-    async def aprint_arguments(self):
-        """
-        Displays the wrapped async function's supplied parameters.
-        """
-        for arg in self.arg_tuple:
-            add_to_log(f"Argument:      {repr(arg)}")
-        for kwarg in self.kw_dict.items():
-            add_to_log(f"KW Argument:   {str(kwarg)}")
-
-    async def atime_the_function(self):
-        """
-        Captures the runtime of an async function.
-        """
-        self.time_before = time()
-        self.return_value = await self.timed_func(
-            *self.arg_tuple, **self.kw_dict
-        )
-        self.time_after = time()
-
-    async def aprint_time_elapsed(self):
-        """
-        Displays the captured runtime of the wrapped async funciton.
-        """
-        self.time_elapsed = self.time_after - self.time_before
-        print_string = f"{self.timed_func.__qualname__}\n"
-        print_string += "Time Elapsed:         "
-        print_string += f"{self.time_elapsed} seconds."
-        add_to_log(print_string)
-
-    async def aclose_timer(self):
+    def _close_timer(self):
         """
         Does final calculations on the aggregate runtime statistics of
-        the wrapped async function & displays the results.
+        the wrapped sync function & displays the results.
         """
-        await self.asum_runtimes()
-        await self.aprint_average_runtime()
-        await self.aprint_standard_deviation()
-        await self.aprint_return_value(self.return_value)
-        await self.aprint_source_code()
+        self._sum_runtimes()
+        self.log_entry += [
+            self._output_average_runtime(),
+            self._output_standard_deviation(),
+            self._output_return_value(self.return_value),
+            self._output_trace_call(),
+        ]
+        add_to_log("\n".join(self.log_entry))
 
-    async def asum_runtimes(self):
+    def run(self):
         """
-        Add the runtime of the current wrapped async function's call.
+        Runs the timer.
         """
-        self.timer_sum += self.time_after - self.time_before
-
-    async def aprint_average_runtime(self):
-        """
-        Calculates & displays the average runtime of the wrapped async
-        function.
-        """
-        self.time_average = self.timer_sum / float(self.times_run)
-        add_to_log(f"Average Elapsed Time: {self.time_average} seconds.")
-
-    async def aprint_standard_deviation(self):
-        """
-        Calculates & displays the standard deviation of runtimes of the
-        wrapped async function.
-        """
-        std_deviation = await self.astandard_deviation()
-        print_string = "Standard Deviation:   "
-        print_string += f"{std_deviation} seconds."
-        add_to_log(print_string)
-
-    async def astandard_deviation(self):
-        """
-        Calculates the standard deviation of runtimes of the wrapped
-        async function.
-        """
-        return await self.aaverage_variance() ** 0.5
-
-    async def aaverage_variance(self):
-        """
-        Calculates the variance of runtimes of the wrapped async
-        function.
-        """
-        return await self.asum_of_variances() / self.times_run
-
-    async def asum_of_variances(self):
-        """
-        Adds the current runtime variance to the aggregated sum.
-        """
-        self.variance_sum += (
-            self.time_elapsed - self.time_average
-        ) ** 2
-        return self.variance_sum
-
-    async def aprint_return_value(self, return_value):
-        """
-        Displays the return value of the wrapped async function.
-        """
-        add_to_log(f"Return Value:  {repr(return_value)}")
-
-    async def aprint_source_code(self):
-        """
-        Prints the source code of the currently running wrapped function.
-        """
-        add_to_log(f"Source Code:\n{inspect.getsource(self.timed_func)}")
-
-    @staticmethod
-    async def aprint_trace_call():
-        """
-        Displays the name of the function which has called the wrapped
-        async function in user code by inspecting the stack.
-        """
-        calling_function = inspect.stack()[2][3]
-        add_to_log(f"Calling Function: {calling_function}\n\n")
+        self._start_timer()
+        self._close_timer()
 
 
-class AsyncGenDebugTools(AsyncDebugTools):
+class _AsyncGenDebugTools(AsyncDebugTools):
+
+    __slots__ = ("generator",)
+
     _async_non_none_error = (
         "can't send non-None value to a just-started async generator"
     )
 
-    def _agen_wrapper(self, *a, **kw):
+    def _agen_wrapper(self, func, *a, **kw):
         """
         Creates a wrapper for the async generator being timed that's
         able to in turn be wrapped by ``functools.wraps``.
@@ -417,27 +469,19 @@ class AsyncGenDebugTools(AsyncDebugTools):
             Increments the wrapped async generator then takes runtime
             measurements & displays the results.
             """
+            self.func = func
+            self.generator = func(*a, **kw)
             while True:
                 try:
-                    await self.ainitiate_timer_func(*a, **kw)
-                    await self.astart_the_timer(self.timed_func)
-                    await self.aclose_timer()
-                    await self.aprint_trace_call()
+                    await self.ainitialize_run(func, *a, **kw)
+                    await self.arun()
                     yield self.return_value
                 except StopAsyncIteration:
                     break
 
         return _agen
 
-    async def aprint_happening_now(self, decorated_func):
-        """
-        Displays the currently running wrapped async generator.
-        """
-        print_string = f"Function:\t{decorated_func.__qualname__}\n"
-        print_string += f"{repr(decorated_func)}"
-        add_to_log(print_string)
-
-    async def atime_the_function(self):
+    async def _atime_the_function(self):
         """
         Captures the runtime of an async generator iteration.
         """
@@ -453,21 +497,24 @@ class AsyncGenDebugTools(AsyncDebugTools):
             self.time_after = time()
 
     @staticmethod
-    async def aprint_trace_call():
+    async def _aoutput_trace_call():
         """
         Displays the name of the function which has called the wrapped
         async function in user code by inspecting the stack.
         """
         calling_function = inspect.stack()[5][3], inspect.stack()[2][3]
-        add_to_log(f"Calling Function: {calling_function}\n\n")
+        return f"Calling Function: {calling_function}\n\n"
 
 
-class GenDebugTools(DebugTools):
+class _GenDebugTools(DebugTools):
+
+    __slots__ = ("generator",)
+
     _sync_non_none_error = (
         "can't send non-None value to a just-started generator"
     )
 
-    def _gen_wrapper(self, *a, **kw):
+    def _gen_wrapper(self, func, *a, **kw):
         """
         Creates a wrapper for the generator being timed that's able to
         in turn be wrapped by ``functools.wraps``.
@@ -478,27 +525,19 @@ class GenDebugTools(DebugTools):
             Increments the wrapped generator then takes runtime
             measurements & displays the results.
             """
+            self.func = func
+            self.generator = func(*a, **kw)
             while True:
                 try:
-                    self.initiate_timer_func(*a, **kw)
-                    self.start_the_timer(self.timed_func)
-                    self.close_timer()
-                    self.print_trace_call()
+                    self.initialize_run(func, *a, **kw)
+                    self.run()
                     yield self.return_value
                 except StopIteration:
                     break
 
         return _gen
 
-    def print_happening_now(self, decorated_func):
-        """
-        Displays the currently running wrapped generator.
-        """
-        print_string = f"Function:\t{decorated_func.__qualname__}\n"
-        print_string += f"{repr(decorated_func)}"
-        add_to_log(print_string)
-
-    def time_the_function(self):
+    def _time_the_function(self):
         """
         Captures the runtime of a generator iteration.
         """
@@ -514,16 +553,16 @@ class GenDebugTools(DebugTools):
             self.time_after = time()
 
     @staticmethod
-    def print_trace_call():
+    def _output_trace_call():
         """
         Displays the name of the function which has called the wrapped
         async function in user code by inspecting the stack.
         """
         calling_function = inspect.stack()[5][3], inspect.stack()[2][3]
-        add_to_log(f"Calling Function: {calling_function}\n\n")
+        return f"Calling Function: {calling_function}\n\n"
 
 
-def agen_timer(decorated_func):
+def agen_timer(func):
     """
     A simple timer decorator that can get timings from per-iteration
     readings over an async generator.
@@ -540,45 +579,15 @@ def agen_timer(decorated_func):
         # will now be gathered and printed to the screen.
         pass
     """
-    debugger = AsyncGenDebugTools()
+    debugger = _AsyncGenDebugTools()
 
     def wrapped_generator_func(*a, **kw):
-        debugger.timed_func = decorated_func
-        debugger.generator = decorated_func(*a, **kw)
-        return wraps(decorated_func)(debugger._agen_wrapper(*a, **kw))()
+        return wraps(func)(debugger._agen_wrapper(func, *a, **kw))()
 
     return wrapped_generator_func
 
 
-def afunc_timer(decorated_func):
-    """
-    A simple decorator for async functions which calculates & displays
-    running statistics & introspection details to stdout.
-
-    Usage Example:
-
-    @afunc_timer
-    async def add(x=4, y=6):
-        return x + y
-
-    # Performance statistics & debug info for the async function will be
-    # gathered & printed to the screen whenever it's processed.
-    await add()
-    """
-    debugger = AsyncDebugTools()
-
-    @wraps(decorated_func)
-    async def decorated_func_timed(*a, **kw):
-        await debugger.ainitiate_timer_func(*a, **kw)
-        await debugger.astart_the_timer(decorated_func)
-        await debugger.aclose_timer()
-        await debugger.aprint_trace_call()
-        return debugger.return_value
-
-    return decorated_func_timed
-
-
-def gen_timer(decorated_func):
+def gen_timer(func):
     """
     A simple timer decorator that can get timings from per-iteration
     readings over a sync generator.
@@ -595,17 +604,41 @@ def gen_timer(decorated_func):
         # be gathered and printed to the screen.
         pass
     """
-    debugger = GenDebugTools()
+    debugger = _GenDebugTools()
 
     def wrapped_generator_func(*a, **kw):
-        debugger.timed_func = decorated_func
-        debugger.generator = decorated_func(*a, **kw)
-        return wraps(decorated_func)(debugger._gen_wrapper(*a, **kw))()
+        return wraps(func)(debugger._gen_wrapper(func, *a, **kw))()
 
     return wrapped_generator_func
 
 
-def func_timer(decorated_func):
+def afunc_timer(func):
+    """
+    A simple decorator for async functions which calculates & displays
+    running statistics & introspection details to stdout.
+
+    Usage Example:
+
+    @afunc_timer
+    async def add(x=4, y=6):
+        return x + y
+
+    # Performance statistics & debug info for the async function will be
+    # gathered & printed to the screen whenever it's processed.
+    await add()
+    """
+    debugger = AsyncDebugTools()
+
+    @wraps(func)
+    async def wrapped_func(*a, **kw):
+        await debugger.ainitialize_run(func, *a, **kw)
+        await debugger.arun()
+        return debugger.return_value
+
+    return wrapped_func
+
+
+def func_timer(func):
     """
     A simple decorator for sync functions which calculates & displays
     running statistics & introspection details to stdout.
@@ -622,47 +655,27 @@ def func_timer(decorated_func):
     """
     debugger = DebugTools()
 
-    @wraps(decorated_func)
-    def decorated_func_timed(*a, **kw):
-        debugger.initiate_timer_func(*a, **kw)
-        debugger.start_the_timer(decorated_func)
-        debugger.close_timer()
-        debugger.print_trace_call()
+    @wraps(func)
+    def wrapped_func(*a, **kw):
+        debugger.initialize_run(func, *a, **kw)
+        debugger.run()
         return debugger.return_value
 
-    return decorated_func_timed
-
-
-async_timers = dict(
-    agen_timer=agen_timer, afunc_timer=afunc_timer
-)
-
-
-sync_timers = dict(
-    gen_timer=gen_timer, func_timer=func_timer
-)
-
-
-for name, method in  async_timers.items():
-    setattr(AsyncDebugTools, name, method)
-
-
-for name, method in  sync_timers.items():
-    setattr(DebugTools, name, method)
+    return wrapped_func
 
 
 extras = dict(
-    AsyncDebugGenTools=AsyncGenDebugTools,
     AsyncDebugTools=AsyncDebugTools,
     DebugControl=DebugControl,
-    DebugGenTools=GenDebugTools,
     DebugTools=DebugTools,
     __doc__=__doc__,
     __main_exports__=__all__,
     __package__=__package__,
     add_to_log=print,
-    **async_timers,
-    **sync_timers,
+    afunc_timer=afunc_timer,
+    agen_timer=agen_timer,
+    func_timer=func_timer,
+    gen_timer=gen_timer,
 )
 
 
